@@ -30,11 +30,15 @@ class Store:
 
     "A convenience wrapper around RDF stores."
 
-    def __init__(self, store):
+    def __init__(self, store, base_uri="/"):
 
-        "Initialise with a store found with the given underlying 'store'."
+        """
+        Initialise with a store found with the given underlying 'store' and an
+        optional 'base_uri' which can be used to qualify URI references.
+        """
 
         self.cstore = store
+        self.base_uri = self.cstore.Namespace(base_uri)
 
         # Copy in useful attributes.
 
@@ -202,23 +206,31 @@ class Store:
             yield property_type, property_value
 
     # Reporting methods.
+    # These methods are used to supply templates with item information.
 
-    def fill_element_serialised(self, doc, element, items):
+    def fill_element_serialised(self, doc, element, items, qualifier=None):
 
         """
         Within the given document 'doc', inside the given 'element', insert the
         XML serialisation of each item in the supplied 'items'.
+
+        The fill_element_serialised method provides an accurate rendition of
+        each item in RDFCalendar's XML format.
         """
 
-        for item in items:
-            item_type = self.get_item_type(item)
-            write_to_document(doc, element, self.cstore, nodes=[item], value_as_attribute=1)
+        write_to_document(doc, element, self.cstore, nodes=items, qualifier=qualifier, value_as_attribute=1)
 
     def fill_element(self, doc, element, items, element_name="item", top_level=1):
 
         """
         Within the given document 'doc', inside the given 'element', insert the
-        top-level details of the given 'items'.
+        top-level details of the given 'items'. Each item will be represented by
+        an element of the optional 'element_name' (or the default name, "item").
+
+        The fill_element method provides item summaries, more appropriate for
+        list views. Typically, each item will look something like this:
+
+        <item item-value="..." item-type="..." prop1="..." prop2="..." />
         """
 
         for item in items:
@@ -232,13 +244,26 @@ class Store:
             for property_type, property_value in self.get_item_properties(item):
                 label = self.get_label(property_type)
 
+                # Write property values to attributes.
+
                 if isinstance(property_value, self.Literal):
                     item_element.setAttribute(label, unicode(property_value))
+
+                # Write item types out nicely.
+
                 elif label == "item-type":
                     item_element.setAttribute(label, self.get_label(property_value))
+
+                # Write entire items out at the top level.
+
                 elif top_level:
                     self.fill_element(doc, item_element, [property_value], label, 0)
 
+                # For URIRef-based properties, write identifiers out.
+
+                else:
+                    item_element.setAttribute(label, self.get_identifier_from_item(property_value))
+
     # Update methods.
 
     def add_item(self, item, doc):
@@ -266,53 +291,100 @@ class Store:
 
         """
         Return an item built from the given 'identifier'. Here, we distinguish
-        between BNode, URIRef and URIRef including a uid as follows:
+        between BNode, URIRef including a uid, URIRef within the store, and
+        other URIRef items as follows:
 
-        BNode           starts with _
-        URIRef          unprefixed, will typically start with a URL "protocol"
-        URIRef/uid      starts with -
+        BNode                               starts with _
+        URIRef/uid                          starts with --
+        URIRef within base URI for store    unprefixed (add the base URI)
+        URIRef                              starts with -
         """
 
-        # NOTE: Detect BNode objects.
         if identifier.startswith("_"):
             return self.BNode(identifier)
+        elif identifier.startswith("--"):
+            return self.URIRef(self.rdfcalendar_uid + identifier[2:])
         elif identifier.startswith("-"):
-            return self.URIRef(self.rdfcalendar_uid + identifier[1:])
+            return self.URIRef(identifier[1:])
         else:
-            return self.URIRef(identifier)
+            return self.base_uri[identifier]
+
+    def get_item_from_reference(self, reference):
+
+        """
+        Similar to get_item_from_identifer, but with a narrower range of types,
+        return an item for the given 'reference' according to the following
+        mapping:
+
+        BNode                               starts with _
+        URIRef                              all other symbols
+
+        NOTE: This is dependent on referenced items being defined by/under BNode
+        NOTE: objects, but this is probably going to be phased out.
+        """
+
+        if reference.startswith("_"):
+            return self.BNode(reference)
+        else:
+            return self.URIRef(reference)
 
     def get_identifier_from_item(self, item):
 
         """
         Return an identifier built from the given 'item'. Here, we distinguish
-        between BNode, URIRef and URIRef including a uid as follows:
+        between BNode, URIRef including a uid, URIRef within the store, and
+        other URIRef items as follows:
 
-        BNode           starts with _
-        URIRef          unprefixed, will typically start with a URL "protocol"
-        URIRef/uid      starts with -
+        BNode                               starts with _
+        URIRef/uid                          starts with --
+        URIRef within base URI for store    unprefixed (remove the base URI)
+        URIRef                              starts with -
         """
 
         item_str = unicode(item)
 
-        if isinstance(item, self.URIRef) and item_str.startswith(self.rdfcalendar_uid):
-            # NOTE: Taken from RDFCalendar.
-            return "-" + item_str[len(self.rdfcalendar_uid):]
+        if isinstance(item, self.URIRef):
+            # URIRef/uid:
+            if item_str.startswith(self.rdfcalendar_uid):
+                # NOTE: Taken from RDFCalendar.
+                return "--" + item_str[len(self.rdfcalendar_uid):]
+            # URIRef within base URI for store:
+            elif item_str.startswith(unicode(self.base_uri)):
+                return item_str[len(unicode(self.base_uri)):]
+            # Other URIRef:
+            else:
+                return "-" + item_str
         else:
-            # BNodes should begin with _ and other URIRefs remain unprefixed.
+            # BNodes should begin with _.
             return unicode(item)
 
     # Convenience methods.
 
     def get_label(self, identifier):
+
+        "Return a label for a (typically) type-based 'identifier'."
+
         if identifier == self.TYPE:
             return "item-type"
         else:
             return self.cstore.get_label(identifier)
 
     def get_uid(self, identifier):
+
+        """
+        Return a unique identifier label for the given 'identifier' or None
+        if the 'identifier' cannot be interpreted in such a way.
+        """
+
         return self.cstore.get_uid(identifier)
 
     def get_uriref(self, item):
+
+        """
+        Return the given 'item' as a URIRef or None if the 'item' is not of a
+        compatible/equivalent nature.
+        """
+
         if isinstance(item, self.URIRef):
             return item
         else:
@@ -354,7 +426,7 @@ class Store:
             return None
         elif property_type == self.TYPE:
             return self.get_item_type_from_identifier(value)
-        elif property_type == self.rdfcalendar["related-to"]:
+        elif property_type in (self.rdfcalendar["related-to"], self.rdfcalendar["uri"]):
             return self.get_item_from_identifier(value)
         else:
             return self.Literal(value)
@@ -517,9 +589,12 @@ class Store:
             found_items = self.combine_items(found_items, result)
         return found_items
 
-def open(store_name, store_type, context=None):
-    store = RDFCalendar.Store.open(store_name, store_type, context)
-    return Store(store)
+def open(store_name, store_type, base_uri=None, context=None, **kw):
+    store = RDFCalendar.Store.open(store_name, store_type, context, **kw)
+    if base_uri is not None:
+        return Store(store, base_uri)
+    else:
+        return Store(store)
 
 def unique(l):
     d = {}
