@@ -315,8 +315,15 @@ class ItemSelectorResource:
             # For POST methods...
 
             elif trans.get_request_method() == "POST" and len(vpath_fields) > 1:
-                self.editor.respond(trans)
-                raise EndOfResponse
+
+                # Detect filter view actions.
+
+                if attributes.has_key("filter-type"):
+                    self.viewer.respond(trans)
+                    raise EndOfResponse
+                else:
+                    self.editor.respond(trans)
+                    raise EndOfResponse
 
             # For PROPFIND methods, provide a special property listing.
 
