@@ -36,12 +36,16 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
     resource_dir = os.path.join(os.path.split(__file__)[0], "Resources")
     encoding = "utf-8"
+    path_encoding = "utf-8"
     template_resources = {
         "items_calendar" : ("items_calendar_template.xhtml", "items_calendar_output.xsl")
         }
     transform_resources = {
         "items_calendar_sort" : ["items_calendar_sort.xsl"]
         }
+    document_resources = {
+        "translations" : "translations.xml"
+        }
 
     # View configuration.
 
@@ -57,6 +61,11 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         'form' information.
         """
 
+        # Get paths, specifically the parent, since this will be used to
+        # redirect to new resource editors.
+
+        pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
+
         # Find the date information.
 
         attributes = trans.get_attributes()
@@ -77,6 +86,30 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
             export_items(found_items, self.store, stream)
             raise EndOfResponse
 
+        elif parameters.has_key("new-event"):
+            if attributes.has_key("filter-type"):
+                new_path = trans.update_path(pvpath, "../../event/new/")
+            else:
+                new_path = trans.update_path(pvpath, "../event/new/")
+            trans.redirect(trans.encode_path(new_path, self.path_encoding))
+            # Response ended!
+
+        elif parameters.has_key("new-to-do"):
+            if attributes.has_key("filter-type"):
+                new_path = trans.update_path(pvpath, "../../to-do/new/")
+            else:
+                new_path = trans.update_path(pvpath, "../to-do/new/")
+            trans.redirect(trans.encode_path(new_path, self.path_encoding))
+            # Response ended!
+
+        elif parameters.has_key("new-card"):
+            if attributes.has_key("filter-type"):
+                new_path = trans.update_path(pvpath, "../../card/new/")
+            else:
+                new_path = trans.update_path(pvpath, "../card/new/")
+            trans.redirect(trans.encode_path(new_path, self.path_encoding))
+            # Response ended!
+
         # Produce a new document.
 
         items = form.new_instance("items")
@@ -119,9 +152,20 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         trans_xsl = self.prepare_output("items_calendar")
 
+        # Get the translations.
+
+        translations_xml = self.prepare_document("translations")
+        languages = trans.get_content_languages()
+        try:
+            language = languages[0]
+        except IndexError:
+            language = ""
+        stylesheet_parameters["locale"] = language
+
         # Complete the response.
 
-        self.send_output(trans, [trans_xsl], items, stylesheet_parameters)
+        self.send_output(trans, [trans_xsl], items, stylesheet_parameters,
+            references={"translations" : translations_xml})
 
 class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
@@ -136,6 +180,9 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
     transform_resources = {
         "items_sort" : ["items_sort.xsl"]
         }
+    document_resources = {
+        "translations" : "translations.xml"
+        }
 
     # View configuration.
 
@@ -155,7 +202,6 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # redirect to new resource editors.
 
         pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
-        parent_path = trans.update_path(pvpath, "..")
 
         # Get the items in the form.
 
@@ -195,7 +241,6 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # Filter according to supplied criteria.
 
         found_items = self.store.get_items_using_attributes(attributes, self.default_item_types)
-        found_selected_items = self.store.get_selected_items(selected_items)
 
         # Check for download actions or editing actions.
 
@@ -210,21 +255,30 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         elif parameters.has_key("download"):
             trans.set_content_type(ContentType("text/calendar", self.encoding))
             stream = trans.get_response_stream()
-            export_items(found_selected_items, self.store, stream)
+            export_items(selected_items, self.store, stream)
             raise EndOfResponse
 
         elif parameters.has_key("new-event"):
-            new_path = trans.update_path(parent_path, "event/new/")
+            if attributes.has_key("filter-type"):
+                new_path = trans.update_path(pvpath, "../../event/new/")
+            else:
+                new_path = trans.update_path(pvpath, "../event/new/")
             trans.redirect(trans.encode_path(new_path, self.path_encoding))
             # Response ended!
 
         elif parameters.has_key("new-to-do"):
-            new_path = trans.update_path(parent_path, "to-do/new/")
+            if attributes.has_key("filter-type"):
+                new_path = trans.update_path(pvpath, "../../to-do/new/")
+            else:
+                new_path = trans.update_path(pvpath, "../to-do/new/")
             trans.redirect(trans.encode_path(new_path, self.path_encoding))
             # Response ended!
 
         elif parameters.has_key("new-card"):
-            new_path = trans.update_path(parent_path, "card/new/")
+            if attributes.has_key("filter-type"):
+                new_path = trans.update_path(pvpath, "../../card/new/")
+            else:
+                new_path = trans.update_path(pvpath, "../card/new/")
             trans.redirect(trans.encode_path(new_path, self.path_encoding))
             # Response ended!
 
@@ -267,9 +321,20 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         trans_xsl = self.prepare_output("items")
 
+        # Get the translations.
+
+        translations_xml = self.prepare_document("translations")
+        languages = trans.get_content_languages()
+        try:
+            language = languages[0]
+        except IndexError:
+            language = ""
+        stylesheet_parameters["locale"] = language
+
         # Complete the response.
 
-        self.send_output(trans, [trans_xsl], items, stylesheet_parameters)
+        self.send_output(trans, [trans_xsl], items, stylesheet_parameters,
+            references={"translations" : translations_xml})
 
 # WebDAV-oriented resources.
 
