@@ -21,7 +21,7 @@ If not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 """
 
-__version__ = "0.1.1"
+__version__ = "0.1.3"
 
 import os
 
@@ -56,6 +56,7 @@ def get_site(store):
     directory = os.path.join(os.path.split(__file__)[0], "Resources")
     styles_dir = DirectoryResource(os.path.join(directory, "styles"), {"css" : "text/css"})
     scripts_dir = DirectoryResource(os.path.join(directory, "scripts"), {"js" : "text/javascript"})
+    images_dir = DirectoryResource(os.path.join(directory, "images"), {"png" : "image/png", "svg" : "image/svg+xml"})
     webdav_root = RootViewerResource()
     webdav_months = MonthViewerResource()
 
@@ -86,6 +87,7 @@ def get_site(store):
     view_choices = MapResource({
         "styles" : styles_dir,
         "scripts" : scripts_dir,
+        "images" : images_dir,
         "" : ViewSelectorResource(list_viewer_resource, calendar_viewer_resource, prop_viewer_resource)
         })
 
