@@ -17,27 +17,11 @@ cwd = os.path.split(program)[0]
 applications = os.path.join(cwd, "applications")
 if os.path.exists(applications):
     sys.path.insert(0, applications)
+server_dir = os.path.join(cwd, "servers", "BaseHTTPRequestHandler")
+if os.path.exists(server_dir):
+    sys.path.insert(0, server_dir)
 
-from WebStack.Adapters.BaseHTTPRequestHandler import deploy
-import WebCalendar
-import WebCalendar.RDFAccess
-
-# Get the store.
-
-if len(sys.argv) > 2:
-    store = WebCalendar.RDFAccess.open(sys.argv[1], sys.argv[2])
-else:
-    print "Need a store name and a store type (rdflib or sqltriples)."
-    sys.exit(1)
-
-# Get a simple Web site.
-
-resource = WebCalendar.get_site(store)
-
-print "Serving..."
-try:
-    deploy(resource, handle_errors=0)
-finally:
-    store.close()
+import WebCalendarApp
+sys.exit(WebCalendarApp.main(sys.argv))
 
 # vim: tabstop=4 expandtab shiftwidth=4
